from fairies import same_pinyin
from fairies import same_stroke
from fairies import hanzi

def get_tongyin():
    
    return same_pinyin.tongyin

def get_tongxing():
   
    return same_stroke.tongxing

def get_hanzi():

    return hanzi.hanzi
